@@ -11,17 +11,38 @@ pub use salvo_core as core;
 pub use salvo_core::*;
 
 #[cfg(any(
+    feature = "extra",
     feature = "basic_auth",
     feature = "compression",
     feature = "cors",
     feature = "csrf",
     feature = "jwt-auth",
+    feature = "logging",
     feature = "proxy",
     feature = "serve-static",
     feature = "session",
     feature = "size-limiter",
     feature = "sse",
-    feature = "ws",
-    feature = "logging"
+    feature = "timeout",
+    feature = "ws"
 ))]
+#[cfg_attr(
+    docsrs,
+    doc(cfg(any(
+        feature = "extra",
+        feature = "basic_auth",
+        feature = "compression",
+        feature = "cors",
+        feature = "csrf",
+        feature = "jwt-auth",
+        feature = "logging",
+        feature = "proxy",
+        feature = "serve-static",
+        feature = "session",
+        feature = "size-limiter",
+        feature = "sse",
+        feature = "timeout",
+        feature = "ws"
+    )))
+)]
 pub use salvo_extra as extra;
